rackspace
    * ``auth_account`` Specify account number for authentication

    * ``auth_username`` Specify username for authentication. only used if --auth-token is empty.

    * ``auth_api_key`` Specify api key for authentication. only used if --auth-token is empty.

    * ``auth_token`` Specify token for authentication. if empty, the username and api key will be used to create a token.

    * ``sleep_time`` Number of seconds to wait between update requests.
